%?python_enable_dependency_generator

Summary:        Cross-platform, Python-agnostic binary package manager
Name:           conda
Version:        23.9.0
Release:        2%{?dist}
License:        BSD-3-Clause AND Apache-2.0 
URL:            http://conda.pydata.org/docs/
Source0:        https://github.com/conda/conda/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/tartansandal/conda-bash-completion/1.7/conda

Patch3000:      conda_sys_prefix.patch
Patch3001:      0001-Use-main-entry-point-for-conda-and-re-add-conda-env-.patch
Patch3002:      conda-cpuinfo.patch
Patch3003:      0004-Do-not-try-to-run-usr-bin-python.patch
Patch3004:      0005-Fix-failing-tests-in-test_api.py.patch
Patch3005:      0006-shell-assume-shell-plugins-are-in-etc.patch

BuildRequires:  pkgconfig(bash-completion) sed
Requires:       python%{python3_pkgversion}-conda = %{version}-%{release}

BuildArch:      noarch

%description
Conda is a cross-platform, Python-agnostic binary package manager. It is the
package manager used by Anaconda installations, but it may be used for other
systems as well. Conda makes environments first-class citizens, making it easy
to create independent environments even for C libraries. Conda is written
entirely in Python.

%package -n python%{python3_pkgversion}-conda
Summary:        Cross-platform, Python-agnostic binary package manager
BuildRequires:  python%{python3_pkgversion}-devel

# for tests
BuildRequires:  python-unversioned-command python%{python3_pkgversion}-pytest-rerunfailures
BuildRequires:  python%{python3_pkgversion}-boto3 python%{python3_pkgversion}-pytest-timeout
BuildRequires:  python%{python3_pkgversion}-flask python%{python3_pkgversion}-pytest-xprocess
BuildRequires:  python%{python3_pkgversion}-jsonpatch python%{python3_pkgversion}-pytest-mock
BuildRequires:  python%{python3_pkgversion}-responses

# bundled versions in conda/_vendor/vendor.txt
Provides:       bundled(python%{python3_pkgversion}-appdirs) = 1.2.0
Provides:       bundled(python%{python3_pkgversion}-auxlib) = 0.0.43
Provides:       bundled(python%{python3_pkgversion}-boltons) = 21.0.0

%description -n python%{python3_pkgversion}-conda
Conda is a cross-platform, Python-agnostic binary package manager. It is the
package manager used by Anaconda installations, but it may be used for other
systems as well. Conda makes environments first-class citizens, making it easy
to create independent environments even for C libraries. Conda is written
entirely in Python.

%prep
%autosetup -n %{name}-%{version} -p1

sed -i -e '/ruamel.yaml/s/,<[0-9.]*//' pyproject.toml
sed -i -e '/splitting-algorithm/d' -e '/store-durations/d' -e '/xdoctest/d' pyproject.toml
sed -r -i '1 {/#![/]usr[/]bin[/]env/d}' conda/_vendor/appdirs.py

rm -r conda/_vendor/cpuinfo
sed -i -e '/^dependencies = /a\ \ "py-cpuinfo",' pyproject.toml

rm -r conda/_vendor/{distro.py,frozendict}
find conda -name \*.py | xargs sed -i -e 's/^\( *\)from .*_vendor\.\(\(distro\|frozendict\).*\) import/\1from \2 import/'
sed -i -e '/^dependencies = /a\ \ "distro",' pyproject.toml
sed -i -e '/^dependencies = /a\ \ "frozendict",' pyproject.toml

sed -i -e '/"boltons *>/d' pyproject.toml
sed -i -e '/"truststore *>/d' pyproject.toml

%ifnarch x86_64
cp -a tests/data/conda_format_repo/{linux-64,%{python3_platform}}
sed -i -e s/linux-64/%{python3_platform}/ tests/data/conda_format_repo/%{python3_platform}/*json
%endif

sed -i -e '/"--cov/d' pyproject.toml

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%py3_shebang_fix %{buildroot}%{python3_sitelib}/conda/shell/bin/conda
%pyproject_save_files conda conda_env

mkdir -p %{buildroot}%{_sysconfdir}/conda/condarc.d
mkdir -p %{buildroot}%{_datadir}/conda/condarc.d
cat >%{buildroot}%{_datadir}/conda/condarc.d/defaults.yaml <<EOF
pkgs_dirs:
 - /var/cache/conda/pkgs
 - ~/.conda/pkgs
EOF

rm -rf %{buildroot}%{python3_sitelib}/tests

mkdir -p %{buildroot}%{_localstatedir}/cache/conda/pkgs/cache

install -m 0644 -Dt %{buildroot}%{_sysconfdir}/profile.d/ conda/shell%{_sysconfdir}/profile.d/conda.{sh,csh}
sed -r -i -e '1i [ -z "$CONDA_EXE" ] && CONDA_EXE=%{_bindir}/conda' \
          -e '/PATH=.*condabin/s|PATH=|[ -d $(dirname "$CONDA_EXE")/condabin ] \&\& PATH=|' %{buildroot}%{_sysconfdir}/profile.d/conda.sh
sed -r -i -e '1i set _CONDA_EXE=%{_bindir}/conda\nset _CONDA_ROOT=' \
          -e 's/CONDA_PFX=.*/CONDA_PFX=/' %{buildroot}%{_sysconfdir}/profile.d/conda.csh
install -m 0644 -Dt %{buildroot}%{_sysconfdir}/fish/conf.d/ conda/shell%{_sysconfdir}/fish/conf.d/conda.fish
sed -r -i -e '1i set -gx CONDA_EXE "/usr/bin/conda"\nset _CONDA_ROOT "/usr"\nset _CONDA_EXE "/usr/bin/conda"\nset -gx CONDA_PYTHON_EXE "/usr/bin/python3"' \
          %{buildroot}%{_sysconfdir}/fish/conf.d/conda.fish

install -m 0644 -Dt %{buildroot}%{bash_completions_dir}/ %{SOURCE1}

%check
export PATH=%{buildroot}%{_bindir}:$PATH
PYTHONPATH=%{buildroot}%{python3_sitelib} conda info
py.test-%{python3_version} -vv -m "not integration" \
    --deselect=tests/test_cli.py::TestJson::test_list \
    --deselect=tests/test_cli.py::test_run_returns_int \
    --deselect=tests/test_cli.py::test_run_returns_nonzero_errorlevel \
    --deselect=tests/test_cli.py::test_run_returns_zero_errorlevel \
    --deselect=tests/test_cli.py::test_run_readonly_env \
    --deselect=tests/test_misc.py::test_explicit_missing_cache_entries \
    --ignore=tests/conda_env/specs/test_binstar.py \
    --deselect=tests/conda_env/test_create.py::test_create_update_remote_env_file \
    --deselect='tests/cli/test_common.py::test_is_active_prefix[active_prefix-True]' \
    --deselect=tests/cli/test_conda_argparse.py::test_list_through_python_api \
    --deselect=tests/cli/test_main_clean.py \
    --deselect=tests/cli/test_main_info.py::test_info_conda_json \
    --deselect=tests/cli/test_main_list.py::test_list \
    --deselect=tests/cli/test_main_list.py::test_list_reverse \
    --deselect=tests/cli/test_main_notices.py::test_notices_appear_once_when_running_decorated_commands \
    --deselect=tests/cli/test_main_notices.py::test_notices_cannot_read_cache_files \
    --deselect=tests/cli/test_main_rename.py \
    --deselect=tests/cli/test_main_run.py \
    --deselect=tests/cli/test_subcommands.py::test_env_create \
    --deselect=tests/cli/test_subcommands.py::test_env_update \
    --deselect=tests/cli/test_subcommands.py::test_init \
    --deselect=tests/cli/test_subcommands.py::test_install \
    --deselect=tests/cli/test_subcommands.py::test_list \
    --deselect=tests/cli/test_subcommands.py::test_notices \
    --deselect=tests/cli/test_subcommands.py::test_remove_all_json[remove] \
    --deselect=tests/cli/test_subcommands.py::test_remove_all_json[uninstall] \
    --deselect=tests/cli/test_subcommands.py::test_rename \
    --deselect=tests/cli/test_subcommands.py::test_run \
    --deselect=tests/cli/test_subcommands.py::test_search \
    --deselect=tests/cli/test_subcommands.py::test_update[update] \
    --deselect=tests/cli/test_subcommands.py::test_update[upgrade] \
    --deselect=tests/core/test_package_cache_data.py::test_ProgressiveFetchExtract_prefers_conda_v2_format \
    --deselect=tests/core/test_subdir_data.py::test_subdir_data_prefers_conda_to_tar_bz2 \
    --deselect=tests/core/test_subdir_data.py::test_use_only_tar_bz2 \
    --deselect=tests/core/test_initialize.py \
    --deselect=tests/core/test_solve.py::test_cuda_fail_1 \
    --deselect=tests/gateways/test_jlap.py::test_download_and_hash \
    --ignore=tests/trust \
    conda tests

%files
%{_bindir}/conda
%{_bindir}/conda-env
%{bash_completions_dir}/conda
%{_sysconfdir}/conda/
%dir %{_sysconfdir}/fish
%dir %{_sysconfdir}/fish/conf.d
%{_sysconfdir}/fish/conf.d/conda.fish
%{_sysconfdir}/profile.d/conda.sh
%{_sysconfdir}/profile.d/conda.csh

%files -n python%{python3_pkgversion}-conda -f %pyproject_files
%doc CHANGELOG.md README.md AUTHORS.md
%{_localstatedir}/cache/conda/
%dir %{_datadir}/conda/
%{_datadir}/conda/condarc.d/

%changelog
* Mon Jul 15 2024 Pengda Dou <doupengda@loongson.cn> - 23.9.0-2
- [Type] other
- [DESC] fix licenses directory not found problem

* Mon Dec 11 2023 Shuo Wang <abushwang@tencent.com> - 23.9.0-1
- initial build
